@@ -168,7 +168,7 @@ class ComplexSTFTDiscriminator(nn.Module):
         n_fft = 1024,
         hop_length = 256,
         win_length = 1024,
-        normalized = False
+        stft_normalized = False
     ):
         super().__init__()
         self.init_conv = ComplexConv2d(input_channels, channels, 7, padding = 3)
@@ -188,7 +188,7 @@ class ComplexSTFTDiscriminator(nn.Module):
 
         # stft settings
 
-        self.normalized = normalized
+        self.stft_normalized = stft_normalized
 
         self.n_fft = n_fft
         self.hop_length = hop_length
@@ -210,7 +210,7 @@ class ComplexSTFTDiscriminator(nn.Module):
             self.n_fft,
             hop_length = self.hop_length,
             win_length = self.win_length,
-            normalized = self.normalized,
+            normalized = self.stft_normalized,
             return_complex = True
         )
 
@@ -358,7 +358,6 @@ class SoundStream(nn.Module):
         multi_spectral_window_powers_of_two = tuple(range(6, 12)),
         multi_spectral_n_ffts = 512,
         multi_spectral_n_mels = 64,
-        multi_spectral_normalized = False,
         recon_loss_weight = 1.,
         multi_spectral_recon_loss_weight = 1.,
         adversarial_loss_weight = 1.,
@@ -447,7 +446,7 @@ class SoundStream(nn.Module):
         self.discriminators = nn.ModuleList([MultiScaleDiscriminator() for _ in range(len(discr_multi_scales))])
 
         self.stft_discriminator = ComplexSTFTDiscriminator(
-            normalized = stft_normalized
+            stft_normalized = stft_normalized
         )
 
         # multi spectral reconstruction
@@ -473,7 +472,7 @@ class SoundStream(nn.Module):
                 win_length = win_length,
                 hop_length = win_length // 4,
                 n_mels = n_mels,
-                normalized = multi_spectral_normalized
+                normalized = stft_normalized
             )
 
             self.mel_spec_transforms.append(melspec_transform)
